check_row_na: Find number of and which rows contain any missingness
Description
Find number of and which rows contain any missingness
Usage
check_row_na(data, which)
Value
Either an integer value corresponding to the number of rows in data with any missingness (if which = FALSE), or a tibble containing: 1) number of rows in data with any missingness, and 2) a list of which rows/row numbers contain missingness (if which = TRUE).
Arguments
data
A data frame or tibble.
which
Logical. Should a list be returned with the row numbers corresponding to each row with missingness? Default set to FALSE.